@@ -15,6 +15,7 @@ from prance import ResolvingParser
 
 from aionetbox.exceptions import (
     BadRequest,
+    ClientFilterError,
     MissingRequiredParam,
     InvalidResponse,
     InvalidRequest,
@@ -292,13 +293,15 @@ class NetboxApiOperation:
             body=body
         )
 
-        resp.raise_for_status()
-        data = await resp.json()
+        if resp.status >= 400:
+            raise ClientFilterError(message=await resp.json())
 
         if method.upper() == 'DELETE':
             # if we're here, it means raise_for_status is cool and we're doing a delete, so lets just return a bool
             return True
 
+        data = await resp.json()
+
         return NetboxResponseObject.from_response(
             data=data,
             **self.config.get('responses', {}).get(str(resp.status), {}).get('schema', {})
